=======
Credits
=======


Development Lead
----------------

* K.-Michael Aye <kmichael.aye@gmail.com>

Contributors
------------

* Eliot Young
* Mark Bullock


Initial development
-------------------

Mostly in the form of Jupyter notebooks

* Nicolas Ardavin
* Kenyon Prater 
